.. _combinatorics-partitions:

Partitions
==========

.. module:: diofant.combinatorics.partitions

.. autoclass:: Partition
   :members:

.. autoclass:: IntegerPartition
   :members:

.. autofunction:: random_integer_partition

.. autofunction:: RGS_generalized

.. autofunction:: RGS_enum

.. autofunction:: RGS_unrank

.. autofunction:: RGS_rank
